==> skill-core-0.0.4-sources.jar: com/ptteng/sca/common/skill/client/MessageSCAClient.java <==
/**
 * 
 */
package com.ptteng.sca.common.skill.client;

import java.util.List;
import java.util.Map;

import com.ptteng.common.skill.model.Message;
import com.ptteng.common.skill.service.MessageService;
import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;

public class MessageSCAClient implements MessageService {

    private MessageService messageService;

	public MessageService getMessageService() {
		return messageService;
	}
	
	
	public void setMessageService(MessageService messageService) {
		this.messageService =messageService;
	}
	
	
			   
		@Override
		public Long insert(Message message)throws ServiceException, ServiceDaoException{
		
		return messageService.insert(message);
		          
		
		}	
		  
    	   
		@Override
		public List<Message> insertList(List<Message> messageList)throws ServiceException, ServiceDaoException{
		
		return messageService.insertList(messageList);
		          
		
		}	
		  
    	   
		@Override
		public boolean delete(Long id)throws ServiceException, ServiceDaoException{
		
		return messageService.delete(id);
		          
		
		}	
		  
    	   
		@Override
		public boolean update(Message message)throws ServiceException, ServiceDaoException{
		
		return messageService.update(message);
		          
		
		}	
		  
    	   
		@Override
		public boolean updateList(List<Message> messageList)throws ServiceException, ServiceDaoException{
		
		return messageService.updateList(messageList);
		          
		
		}	
		  
    	   
		@Override
		public Message getObjectById(Long id)throws ServiceException, ServiceDaoException{
		
		return messageService.getObjectById(id);
		          
		
		}	
		  
    	   
		@Override
		public List<Message> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException{
		
		return messageService.getObjectsByIds(ids);
		          
		
		}	
		  
    	
	
	
	
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getMessageIdsBySendIdAndStatus(Long sendId,Integer status,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return messageService.getMessageIdsBySendIdAndStatus(sendId,status,start,limit);
	
	
	}

	@Override
	public List<Long> getMessageIdsByReceiveIdAndUnreadAndStatus(Long receiveId, Integer unread, Integer status, Integer start, Integer limit) throws ServiceException, ServiceDaoException {
		return messageService.getMessageIdsByReceiveIdAndUnreadAndStatus(receiveId, unread, status, start, limit);
	}

	@Override
	public List<Long> getMessageIdsByReceiveIdAndUnreadAndStatusAndType(Long receiveId, Integer unread, Integer status, String type, Integer start, Integer limit) throws ServiceException, ServiceDaoException {
		return messageService.getMessageIdsByReceiveIdAndUnreadAndStatusAndType(receiveId, unread, status, type, start, limit);
	}


	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getMessageIdsByReceiveIdAndStatus(Long receiveId,Integer status,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return messageService.getMessageIdsByReceiveIdAndStatus(receiveId,status,start,limit);
	
	
	}
	
		
	
	
    			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countMessageIdsBySendIdAndStatus(Long sendId,Integer status)throws ServiceException, ServiceDaoException{
		
		return messageService.countMessageIdsBySendIdAndStatus(sendId,status);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countMessageIdsByReceiveIdAndStatus(Long receiveId,Integer status)throws ServiceException, ServiceDaoException{
		
		return messageService.countMessageIdsByReceiveIdAndStatus(receiveId,status);
	
	
	}
	
		
	
		@Override
	public List<Long> getMessageIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return messageService.getMessageIds(start, limit);
	}

	@Override
	public Integer countMessageIds() throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return messageService.countMessageIds();
	}
	
	
	@Override
	public List<Long> getIdsByDynamicCondition(Class clz, Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return messageService.getIdsByDynamicCondition(clz, conditions, start, limit);
	}


	@Override
	public boolean fakeDelete(Class clz, Long id) throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return messageService.fakeDelete(clz, id);
	}
	
	
	
	@Override
	public void deleteList(Class clz, List<Long> ids) throws ServiceException, ServiceDaoException {
		   messageService.deleteList(clz, ids);
		
	}


 
}

==> skill-core-1.12.4-sources.jar: com/ptteng/sca/common/skill/client/MessageSCAClient.java <==
/**
 * 
 */
package com.ptteng.sca.common.skill.client;

import java.util.List;
import java.util.Map;

import com.ptteng.common.skill.model.Message;
import com.ptteng.common.skill.service.MessageService;
import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;

public class MessageSCAClient implements MessageService {

    private MessageService messageService;

	public MessageService getMessageService() {
		return messageService;
	}
	
	
	public void setMessageService(MessageService messageService) {
		this.messageService =messageService;
	}
	
	
			   
		@Override
		public Long insert(Message message)throws ServiceException, ServiceDaoException{
		
		return messageService.insert(message);
		          
		
		}	
		  
    	   
		@Override
		public List<Message> insertList(List<Message> messageList)throws ServiceException, ServiceDaoException{
		
		return messageService.insertList(messageList);
		          
		
		}	
		  
    	   
		@Override
		public boolean delete(Long id)throws ServiceException, ServiceDaoException{
		
		return messageService.delete(id);
		          
		
		}	
		  
    	   
		@Override
		public boolean update(Message message)throws ServiceException, ServiceDaoException{
		
		return messageService.update(message);
		          
		
		}	
		  
    	   
		@Override
		public boolean updateList(List<Message> messageList)throws ServiceException, ServiceDaoException{
		
		return messageService.updateList(messageList);
		          
		
		}	
		  
    	   
		@Override
		public Message getObjectById(Long id)throws ServiceException, ServiceDaoException{
		
		return messageService.getObjectById(id);
		          
		
		}	
		  
    	   
		@Override
		public List<Message> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException{
		
		return messageService.getObjectsByIds(ids);
		          
		
		}	
		  
    	
	
	
	
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getMessageIdsBySendIdAndStatus(Long sendId,Integer status,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return messageService.getMessageIdsBySendIdAndStatus(sendId,status,start,limit);
	
	
	}

	@Override
	public List<Long> getMessageIdsByReceiveIdAndUnreadAndStatus(Long receiveId, Integer unread, Integer status, Integer start, Integer limit) throws ServiceException, ServiceDaoException {
		return messageService.getMessageIdsByReceiveIdAndUnreadAndStatus(receiveId, unread, status, start, limit);
	}

	@Override
	public List<Long> getMessageIdsByReceiveIdAndUnreadAndStatusAndType(Long receiveId, Integer unread, Integer status, String type, Integer start, Integer limit) throws ServiceException, ServiceDaoException {
		return messageService.getMessageIdsByReceiveIdAndUnreadAndStatusAndType(receiveId, unread, status, type, start, limit);
	}


	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getMessageIdsByReceiveIdAndStatus(Long receiveId,Integer status,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return messageService.getMessageIdsByReceiveIdAndStatus(receiveId,status,start,limit);
	
	
	}

	@Override
	public List<Long> getMessageIdsByReceiveIdAndStatusAndType(Long receiveId, Integer status, String type, Integer start, Integer limit) throws ServiceException, ServiceDaoException {
		return messageService.getMessageIdsByReceiveIdAndStatusAndType(receiveId, status, type, start, limit);
	}


	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countMessageIdsBySendIdAndStatus(Long sendId,Integer status)throws ServiceException, ServiceDaoException{
		
		return messageService.countMessageIdsBySendIdAndStatus(sendId,status);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countMessageIdsByReceiveIdAndStatus(Long receiveId,Integer status)throws ServiceException, ServiceDaoException{
		
		return messageService.countMessageIdsByReceiveIdAndStatus(receiveId,status);
	
	
	}
	
		
	
		@Override
	public List<Long> getMessageIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return messageService.getMessageIds(start, limit);
	}

	@Override
	public Integer countMessageIds() throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return messageService.countMessageIds();
	}
	
	
	@Override
	public List<Long> getIdsByDynamicCondition(Class clz, Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return messageService.getIdsByDynamicCondition(clz, conditions, start, limit);
	}

	@Override
	public Object getObjectByDynamicCondition(Class aClass, Map<String, Object> map, Integer integer, Integer integer1) throws ServiceException, ServiceDaoException {
		return messageService.getObjectByDynamicCondition(aClass, map, integer, integer1);
	}


	@Override
	public boolean fakeDelete(Class clz, Long id) throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return messageService.fakeDelete(clz, id);
	}
	
	
	
	@Override
	public void deleteList(Class clz, List<Long> ids) throws ServiceException, ServiceDaoException {
		   messageService.deleteList(clz, ids);
		
	}


 
}
